@@ -1,10 +1,11 @@
-# Copyright (C) 2015-2024 Joelle Maslak
+#
+# Copyright (C) 2015-2021 Joelle Maslak
 # All Rights Reserved - See License
 #
 
 package JCM::Boilerplate;
 # ABSTRACT: Default Boilerplate for Joelle Maslak's Code
-$JCM::Boilerplate::VERSION = '2.241690';
+$JCM::Boilerplate::VERSION = '2.253340';
 use strict;
 use warnings;
 
@@ -32,8 +33,7 @@ sub import ( $self, $type = 'script' ) {
     warnings->import::into($target);
     autodie->import::into($target);
 
-    my ($ver) = "$PERL_VERSION" =~ m/^v(\d+\.\d+)\..*$/;
-    feature->import::into( $target, ":$ver" );
+    feature->import::into( $target, ':5.22' );
 
     utf8->import::into($target);    # Allow UTF-8 Source
 
@@ -47,8 +47,6 @@ sub import ( $self, $type = 'script' ) {
         Moose::Util::TypeConstraints->import::into($target);
         MooseX::StrictConstructor->import::into($target);
         namespace::autoclean->import::into($target);
-    } else {
-        Feature::Compat::Class->import::into($target);
     }
 
     Carp->import::into($target);
@@ -57,13 +55,11 @@ sub import ( $self, $type = 'script' ) {
 
     feature->import::into( $target, 'postderef' );    # Not needed if feature bundle >= 5.23.1
 
-    Feature::Compat::Defer->import::into($target);
-    Feature::Compat::Try->import::into($target);
-
     # We haven't been using this
     # feature->import::into($target, 'refaliasing');
     feature->import::into( $target, 'signatures' );
 
+    feature->import::into( $target, 'switch' );
     feature->import::into( $target, 'unicode_strings' );
     # warnings->unimport::out_of($target, 'experimental::refaliasing');
     warnings->unimport::out_of( $target, 'experimental::signatures' );
@@ -72,9 +68,12 @@ sub import ( $self, $type = 'script' ) {
         warnings->unimport::out_of( $target, 'experimental::postderef' );
     }
 
+    # For "switch" feature
+    warnings->unimport::out_of( $target, 'experimental::smartmatch' );
+
     # For "re 'strict'" feature
     warnings->unimport::out_of( $target, 'experimental::re_strict' );
-    re->import('strict');
+    re->import( 'strict' );
 
     if ( $PERL_VERSION ge v5.32.0 ) {
         # Turn off indirect syntax
@@ -91,6 +90,10 @@ sub import ( $self, $type = 'script' ) {
 
         # Turn off bareword filehandles
         feature->unimport::out_of( $target, 'bareword_filehandles' );
+
+        # Turn on Try/Catch
+        feature->import::into( $target, 'try' );
+        warnings->unimport::out_of( $target, 'experimental::try' );
     }
 
     return;
@@ -110,18 +113,18 @@ JCM::Boilerplate - Default Boilerplate for Joelle Maslak's Code
 
 =head1 VERSION
 
-version 2.241690
+version 2.253340
 
 =head1 SYNOPSIS
 
-  use JTM::Boilerplate 'script';
+  use JCM::Boilerplate 'script';
 
 =head1 DESCRIPTION
 
 This module serves two purposes.  First, it sets some default imports,
 and turns on the strictures I've come to rely upon.  Secondly, it depends
 on a number of other modules to aid in setting up new environments (I can
-just do a "cpan JTM-Boilerplate" to install everything I need).
+just do a "cpan JCM-Boilerplate" to install everything I need).
 
 This module optionally takes one of two parameters, 'script', 'class',
 or 'role'. If 'script' is specified, the module assumes that you do not
@@ -141,7 +144,7 @@ Joelle Maslak <jmaslak@antelope.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015-2024 by Joelle Maslak.
+This software is copyright (c) 2015-2020 by Joelle Maslak.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
